changeset 14685:496342156d13

Renamed from cal-chinese.el to avoid 14-character limitation.
author Karl Heuer <kwzh@gnu.org>
date Mon, 26 Feb 1996 18:45:24 +0000
parents 66450c507ee4
children 6edb5012f490
files lisp/calendar/cal-china.el
diffstat 1 files changed, 3 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/calendar/cal-china.el	Mon Feb 26 18:45:14 1996 +0000
+++ b/lisp/calendar/cal-china.el	Mon Feb 26 18:45:24 1996 +0000
@@ -1,4 +1,4 @@
 ;;; cal-chinese.el --- calendar functions for the Chinese calendar.
 
 ;; Copyright (C) 1995 Free Software Foundation, Inc.
 
@@ -450,6 +450,6 @@
   "Chinese calendar equivalent of date diary entry."
   (format "Chinese date: %s" (calendar-chinese-date-string date)))
 
-(provide 'cal-chinese)
+(provide 'cal-china)
 
-;;; cal-chinese ends here
+;;; cal-china.el ends here
@@ -1,4 +1,4 @@
-;;; cal-chinese.el --- calendar functions for the Chinese calendar.
+;;; cal-china.el --- calendar functions for the Chinese calendar.
 
 ;; Copyright (C) 1995 Free Software Foundation, Inc.